@@ -671,15 +671,15 @@ class LoadDataset(data.dataset.Dataset):
 
 
 class EmbedDataset:
-    def __init__(self, model, ids_data, vstack_encoded_spectra, store_embed_file, use_gpu):
+    def __init__(self, model, ids_usi_data, vstack_encoded_spectra, store_embed_file, use_gpu):
         self.ids_vstack_df = None
         self.out_list = []
-        self.embedding_dataset(model, ids_data, vstack_encoded_spectra, store_embed_file, use_gpu)
+        self.embedding_dataset(model, ids_usi_data, vstack_encoded_spectra, store_embed_file, use_gpu)
 
     def get_data(self):
         return self.ids_vstack_df
 
-    def embedding_dataset(self, model, ids_data, encoded_spectra_data, store_embed_file, use_gpu):
+    def embedding_dataset(self, model, ids_usi_data, encoded_spectra_data, store_embed_file, use_gpu):
 
         if use_gpu is True:
             # for gpu
@@ -720,8 +720,8 @@ class EmbedDataset:
                 self.out_list = np.vstack((self.out_list, out1))
 
         vstack_data_df = pd.DataFrame({"embedded_spectra": self.out_list.tolist()})
-        self.ids_vstack_df = pd.concat([ids_data, vstack_data_df], axis=1)
-        self.ids_vstack_df.to_csv(store_embed_file, sep="\t", header=True, index=None, columns=["ids", "embedded_spectra"])
+        self.ids_vstack_df = pd.concat([ids_usi_data["ids"], ids_usi_data["usi"], vstack_data_df], axis=1)
+        self.ids_vstack_df.to_csv(store_embed_file, sep="\t", header=True, index=None, columns=["ids", "usi", "embedded_spectra"])
 
 
 def encode_spectra(prj, input_file, reference_spectra,  **kw):
@@ -798,14 +798,14 @@ def embed_spectra(model, ids_usi_data, vstack_encoded_spectra, output_embedd_fil
     else:
         use_gpu = False
 
-    ids_data = ids_usi_data["ids"]
+    # ids_data = ids_usi_data["ids"]
 
-    EmbedDataset(model, ids_data, vstack_encoded_spectra, output_embedd_file, use_gpu)
+    EmbedDataset(model, ids_usi_data, vstack_encoded_spectra, output_embedd_file, use_gpu)
 
     print("Finish spectra embedding, save embedded spectra to " + output_embedd_file + "!")
 
 
-def encode_and_embed_spectra(model, prj, input_file, refrence_spectra):
+def encode_and_embed_spectra(model, refrence_spectra, prj, input_file):
     """
 
     :param model: .pkl format embedding model
